---
name: "Bug Report"
about: Submit a bug report to help us improve audtorch

---

### Bug

Describe the bug.


### Steps to reproduce

List of steps/code to reproduce the bug:

1.
1.


### Expected behaviour

What is the expected outcome.


### Environment

* OS: 
* Python version: 
* audtorch version: 
